bpo-29836: Remove nturl2path from test_sundry and amend the module docstring (GH-694)

The module is implicitly tested through test_urllib.
diff --git a/Lib/nturl2path.py b/Lib/nturl2path.py
index 36dc765..853e660 100644
--- a/Lib/nturl2path.py
+++ b/Lib/nturl2path.py
@@ -1,4 +1,9 @@
-"""Convert a NT pathname to a file URL and vice versa."""
+"""Convert a NT pathname to a file URL and vice versa.
+
+This module only exists to provide OS-specific code
+for urllib.requests, thus do not use directly.
+"""
+# Testing is done through test_urllib.
 
 def url2pathname(url):
     """OS-specific conversion from a relative URL of the 'file' scheme